==> wiredtiger-2.7.0.tar.bz2: wiredtiger-2.7.0/docs/index.js <==
var index =
[
    [ "WiredTiger Architecture", "architecture.html", [
      [ "Multi-core scaling", "architecture.html#multi_core", null ],
      [ "Hot caches", "architecture.html#cache", null ],
      [ "Making I/O more valuable", "architecture.html#io", null ],
      [ "Production quality", "architecture.html#quality", null ],
      [ "NoSQL and Open Source", "architecture.html#nosql", null ]
    ] ],
    [ "Building and installing WiredTiger on POSIX", "build-posix.html", [
      [ "Building using Git and GitHub", "build-posix.html#posix_github", null ],
      [ "Building WiredTiger", "build-posix.html#posix_building", null ],
      [ "Installing WiredTiger", "build-posix.html#posix_installing", null ],
      [ "Configuring WiredTiger", "build-posix.html#posix_configure", null ],
      [ "Changing compiler or loader options", "build-posix.html#posix_compiler", null ]
    ] ],
    [ "Building and installing WiredTiger on Windows", "build-windows.html", [
      [ "Building using Git and GitHub", "build-windows.html#windows_github", null ],
      [ "Building on Windows", "build-windows.html#windows_building", null ],
      [ "Installing WiredTiger", "build-windows.html#windows_installing", null ],
      [ "Configuring WiredTiger", "build-windows.html#windows_configure", null ]
    ] ],
    [ "Building and installing the LevelDB compatibility API", "leveldb.html", [
      [ "Building and using WiredTiger's LevelDB API", "leveldb.html#leveldb_build", null ],
      [ "Caveats", "leveldb.html#leveldb_caveats", null ]
    ] ],
    [ "Writing WiredTiger applications", "programming.html", "programming" ],
    [ "Writing WiredTiger applications  in Java", "programming_lang_java.html", "programming_lang_java" ],
    [ "WiredTiger command line utility", "command_line.html", "command_line" ],
    [ "Managing WiredTiger databases", "admin.html", "admin" ],
    [ "WiredTiger Change Log", "md_changelog.html", null ],
    [ "Upgrading WiredTiger applications", "upgrading.html", [
      [ "Upgrading to Version 2.7.0", "upgrading.html#version_270", null ],
      [ "Upgrading to Version 2.6.1", "upgrading.html#version_261", null ],
      [ "Upgrading to Version 2.6.0", "upgrading.html#version_260", null ],
      [ "Upgrading to Version 2.5.3", "upgrading.html#version_253", null ],
      [ "Upgrading to Version 2.5.2", "upgrading.html#version_252", null ],
      [ "Upgrading to Version 2.5.1", "upgrading.html#version_251", null ],
      [ "Upgrading to Version 2.5.0", "upgrading.html#version_250", null ],
      [ "Upgrading to Version 2.4.1", "upgrading.html#version_241", null ],
      [ "Upgrading to Version 2.4.0", "upgrading.html#version_240", null ],
      [ "Upgrading to Version 2.3.1", "upgrading.html#version_231", null ],
      [ "Upgrading to Version 2.3.0", "upgrading.html#version_230", null ],
      [ "Upgrading to Version 2.2.1", "upgrading.html#version_221", null ],
      [ "Upgrading to Version 2.2.0", "upgrading.html#version_220", null ],
      [ "Upgrading to Version 2.1.2", "upgrading.html#version_212", null ],
      [ "Upgrading to Version 2.1.1", "upgrading.html#version_211", null ],
      [ "Upgrading to Version 2.1", "upgrading.html#version_21", null ],
      [ "Upgrading to Version 2.0", "upgrading.html#version_20", null ],
      [ "Upgrading to Version 1.6.6", "upgrading.html#version_166", null ],
      [ "Upgrading to Version 1.6.5", "upgrading.html#version_165", null ],
      [ "Upgrading to Version 1.6.4", "upgrading.html#version_164", null ],
      [ "Upgrading to Version 1.6.3", "upgrading.html#version_163", null ],
      [ "Upgrading to Version 1.6.2", "upgrading.html#version_162", null ],
      [ "Upgrading to Version 1.6.1", "upgrading.html#version_161", null ],
      [ "Upgrading to Version 1.6.0", "upgrading.html#version_160", null ],
      [ "Upgrading to Version 1.5.3", "upgrading.html#version_153", null ],
      [ "Upgrading to Version 1.4.3", "upgrading.html#version_143", null ],
      [ "Upgrading to Version 1.3.9", "upgrading.html#version_139", null ],
      [ "Upgrading to Version 1.3.8", "upgrading.html#version_138", null ],
      [ "Upgrading to Version 1.3.6", "upgrading.html#version_136", null ],
      [ "Upgrading to Version 1.3.5", "upgrading.html#version_135", null ],
      [ "Upgrading to Version 1.3", "upgrading.html#version_13", null ]
    ] ],
    [ "WiredTiger licensing", "license.html", [
      [ "3rd party software included in the WiredTiger library", "license.html#license_library", null ],
      [ "3rd party software optionally included in the WiredTiger library: LevelDB", "license.html#license_leveldb", null ],
      [ "3rd party software included in the WiredTiger distribution", "license.html#license_distribution", null ],
      [ "Public domain software", "license.html#license_public_domain", null ]
    ] ],
    [ "WiredTiger testing", "testing.html", [
      [ "Unit Test Suite", "testing.html#test_suite", null ],
      [ "Performance Testing", "testing.html#testing_performance", null ],
      [ "Stress Testing", "testing.html#testing_stress", null ],
      [ "Concurrency testing", "testing.html#testing_threads", null ],
      [ "Static analysis", "testing.html#testing_static", null ]
    ] ],
    [ "WiredTiger community and contact information", "community.html", null ]
];

==> wiredtiger_3.2.1.orig.tar.bz2: wiredtiger-3.2.1/docs/index.js <==
var index =
[
    [ "WiredTiger Architecture", "architecture.html", [
      [ "Multi-core scaling", "architecture.html#multi_core", null ],
      [ "Hot caches", "architecture.html#cache", null ],
      [ "Making I/O more valuable", "architecture.html#io", null ],
      [ "Production quality", "architecture.html#quality", null ],
      [ "NoSQL and Open Source", "architecture.html#nosql", null ]
    ] ],
    [ "Building and installing WiredTiger on POSIX", "build-posix.html", [
      [ "Building using Git and GitHub", "build-posix.html#posix_github", null ],
      [ "Building WiredTiger", "build-posix.html#posix_building", null ],
      [ "Installing WiredTiger", "build-posix.html#posix_installing", null ],
      [ "Configuring WiredTiger", "build-posix.html#posix_configure", null ],
      [ "Changing compiler or loader options", "build-posix.html#posix_compiler", null ]
    ] ],
    [ "Building and installing WiredTiger on Windows", "build-windows.html", [
      [ "Building using Git and GitHub", "build-windows.html#windows_github", null ],
      [ "Building on Windows", "build-windows.html#windows_building", null ],
      [ "Installing WiredTiger", "build-windows.html#windows_installing", null ],
      [ "Configuring WiredTiger", "build-windows.html#windows_configure", null ]
    ] ],
    [ "Writing WiredTiger applications", "programming.html", "programming" ],
    [ "Writing WiredTiger applications  in Java", "programming_lang_java.html", "programming_lang_java" ],
    [ "WiredTiger command line utility", "command_line.html", "command_line" ],
    [ "Managing WiredTiger databases", "admin.html", "admin" ],
    [ "WiredTiger Change Log", "md_changelog.html", null ],
    [ "Upgrading WiredTiger applications", "upgrading.html", [
      [ "Upgrading to Version 3.2.1", "upgrading.html#version_321", null ],
      [ "Upgrading to Version 3.1.0", "upgrading.html#version_310", null ],
      [ "Upgrading to Version 3.0.0", "upgrading.html#version_300", null ],
      [ "Upgrading to Version 2.9.2", "upgrading.html#version_292", null ],
      [ "Upgrading to Version 2.9.1", "upgrading.html#version_291", null ],
      [ "Upgrading to Version 2.9.0", "upgrading.html#version_290", null ],
      [ "Upgrading to Version 2.8.0", "upgrading.html#version_280", null ],
      [ "Upgrading to Version 2.7.0", "upgrading.html#version_270", null ],
      [ "Upgrading to Version 2.6.1", "upgrading.html#version_261", null ],
      [ "Upgrading to Version 2.6.0", "upgrading.html#version_260", null ],
      [ "Upgrading to Version 2.5.3", "upgrading.html#version_253", null ],
      [ "Upgrading to Version 2.5.2", "upgrading.html#version_252", null ],
      [ "Upgrading to Version 2.5.1", "upgrading.html#version_251", null ],
      [ "Upgrading to Version 2.5.0", "upgrading.html#version_250", null ],
      [ "Upgrading to Version 2.4.1", "upgrading.html#version_241", null ],
      [ "Upgrading to Version 2.4.0", "upgrading.html#version_240", null ],
      [ "Upgrading to Version 2.3.1", "upgrading.html#version_231", null ],
      [ "Upgrading to Version 2.3.0", "upgrading.html#version_230", null ],
      [ "Upgrading to Version 2.2.1", "upgrading.html#version_221", null ],
      [ "Upgrading to Version 2.2.0", "upgrading.html#version_220", null ],
      [ "Upgrading to Version 2.1.2", "upgrading.html#version_212", null ],
      [ "Upgrading to Version 2.1.1", "upgrading.html#version_211", null ],
      [ "Upgrading to Version 2.1", "upgrading.html#version_21", null ],
      [ "Upgrading to Version 2.0", "upgrading.html#version_20", null ],
      [ "Upgrading to Version 1.6.6", "upgrading.html#version_166", null ],
      [ "Upgrading to Version 1.6.5", "upgrading.html#version_165", null ],
      [ "Upgrading to Version 1.6.4", "upgrading.html#version_164", null ],
      [ "Upgrading to Version 1.6.3", "upgrading.html#version_163", null ],
      [ "Upgrading to Version 1.6.2", "upgrading.html#version_162", null ],
      [ "Upgrading to Version 1.6.1", "upgrading.html#version_161", null ],
      [ "Upgrading to Version 1.6.0", "upgrading.html#version_160", null ],
      [ "Upgrading to Version 1.5.3", "upgrading.html#version_153", null ],
      [ "Upgrading to Version 1.4.3", "upgrading.html#version_143", null ],
      [ "Upgrading to Version 1.3.9", "upgrading.html#version_139", null ],
      [ "Upgrading to Version 1.3.8", "upgrading.html#version_138", null ],
      [ "Upgrading to Version 1.3.6", "upgrading.html#version_136", null ],
      [ "Upgrading to Version 1.3.5", "upgrading.html#version_135", null ],
      [ "Upgrading to Version 1.3", "upgrading.html#version_13", null ]
    ] ],
    [ "WiredTiger licensing", "license.html", [
      [ "3rd party software always included in the WiredTiger library", "license.html#license_library", null ],
      [ "3rd party software optionally included in the WiredTiger library: PPC64", "license.html#license_crc32-power8", null ],
      [ "3rd party software optionally included in the WiredTiger library: s390x", "license.html#license_crc32-zseries", null ],
      [ "3rd party software included in the WiredTiger distribution", "license.html#license_distribution", null ]
    ] ],
    [ "WiredTiger testing", "testing.html", [
      [ "Unit Test Suite", "testing.html#test_suite", null ],
      [ "Performance Testing", "testing.html#testing_performance", null ],
      [ "Stress Testing", "testing.html#testing_stress", null ],
      [ "Concurrency testing", "testing.html#testing_threads", null ],
      [ "Static analysis", "testing.html#testing_static", null ]
    ] ],
    [ "WiredTiger community and contact information", "community.html", null ],
    [ "Developer Documentation", "devdoc-index.html", "devdoc-index" ]
];
